
-------------------------------------------------------------------------------
-- Optimization
-------------------------------------------------------------------------------

-- GLOBALS: HIGHLIGHT_FONT_COLOR, HONOR, Mixin, PVEFrame_ToggleFrame

local BreakUpLargeNumbers = BreakUpLargeNumbers
local C_PvP = C_PvP
local floor = floor
local IsInActiveWorldPVP = IsInActiveWorldPVP
local LEVEL_GAINED = LEVEL_GAINED
local UnitHonor = UnitHonor
local UnitHonorLevel = UnitHonorLevel
local UnitHonorMax = UnitHonorMax

-------------------------------------------------------------------------------
-- Namespace
-------------------------------------------------------------------------------

local A, B, C, D = unpack(SixUI) -- AddOn, Border, Constants, Database
local M = A:NewModule("Display Honor")
local O = LibStub("LibDataBroker-1.1"):NewDataObject("SixUI Honor", {
	description = "Shows while War Mode is enabled, in Battlegrounds, or in world PvP areas.",
	type = "progress bar",
	barR = C.HONOR_RESOURCE_COLOR.r, barG = C.HONOR_RESOURCE_COLOR.g, barB = C.HONOR_RESOURCE_COLOR.b,
	label = HONOR,
	level = UNKNOWN,
	text = UNKNOWN,
	value = "0",
	suffix = "%",
	visible = false,
})

-------------------------------------------------------------------------------
-- Module
-------------------------------------------------------------------------------

function M:OnEnable()
	self:RegisterEvent("HONOR_LEVEL_UPDATE", "Update")
	self:RegisterEvent("HONOR_XP_UPDATE", "Update")
	self:RegisterEvent("PLAYER_FLAGS_CHANGED", "Update")
	self:RegisterEvent("PLAYER_LEVEL_CHANGED", "Update")
	self:RegisterEvent("ZONE_CHANGED_NEW_AREA", "Update")
	self:RegisterEvent("ZONE_CHANGED", "Update")
	self:RegisterMessage("SIXUI_CONFIG_UPDATE", "OnConfigUpdate")
	self:Update()
end

function M:OnConfigUpdate(event, key, ...)
	if key == "color.resource.honor" then
		Mixin(O, {barR = C.HONOR_RESOURCE_COLOR.r, barG = C.HONOR_RESOURCE_COLOR.g, barB = C.HONOR_RESOURCE_COLOR.b})
	end
end

function M:ShouldBeVisible()
	return C_PvP.IsActiveBattlefield() or C_PvP.IsWarModeDesired() or IsInActiveWorldPVP()
end

function M:Update()
	local currentHonor = UnitHonor("player")
	local maxHonor = UnitHonorMax("player")
	local percent = (currentHonor / maxHonor) * 100

	O.level = LEVEL_GAINED:format(UnitHonorLevel("player"))
	O.text = C.XP_TEXT:format(BreakUpLargeNumbers(currentHonor), BreakUpLargeNumbers(maxHonor), floor(percent))
	O.value = percent
	O.visible = self:ShouldBeVisible()
end

-------------------------------------------------------------------------------
-- DataObject
-------------------------------------------------------------------------------

function O.OnClick(frame, button)
	PVEFrame_ToggleFrame("PVPUIFrame", nil)
end

function O.OnTooltipShow(tooltip)
	tooltip:SetText(O.label)
	tooltip:AddLine(O.text, HIGHLIGHT_FONT_COLOR:GetRGB())
	tooltip:AddLine(O.level)
end
